/*
  Copyright (C) 2013-2020 Grégory Soutadé

  This file is part of gPass.

  gPass is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  gPass is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with gPass.  If not, see <http://www.gnu.org/licenses/>.
*/

var default_preferences = {"pbkdf2_level": 1000,
			   "account_url": "https://gpass-demo.soutade.fr/demo",
                           "always_disabled":false
			  };

function get_preference(key)
{
    // Inspired from https://github.com/akiomik/chrome-storage-promise/
    var promise = new Promise((resolve, reject) => {
        chrome.storage.local.get(key, (items) => {
            let err = chrome.runtime.lastError;
            if (err) {
                reject(err);
            } else {
                resolve(items);
            }
        });
    })
	.then(function (pref) {
	    if (!pref.hasOwnProperty(key))
	    {
		if (default_preferences.hasOwnProperty(key))
		    return default_preferences[key];
		else
		    return null;
	    }
	    return pref[key];
	});

    return promise;
}

function set_preference(key, value, sendResponse)
{
    pref = {[key]:value};
    chrome.storage.local.set(pref, function (result) {
	if (chrome.runtime.lastError)
	    alert(chrome.runtime.lastError);
        if (sendResponse)
            sendResponse(chrome.runtime.lastError);
    });
}

function delete_preference(key)
{
    chrome.storage.local.remove(key);
}

function send_tab_message(tab_id, parameters, callback)
{
    chrome.tabs.sendMessage(tab_id, parameters, {}, callback);
}
